@@ -1,5 +1,5 @@
 use std::path::PathBuf;
-use swc_common::{errors::Handler, input::SourceFileInput, Span, Spanned, DUMMY_SP};
+use swc_common::{errors::Handler, input::SourceFileInput, Span, Spanned};
 use swc_css_ast::*;
 use swc_css_parser::{
     error::ErrorKind,
@@ -266,7 +266,7 @@ struct SpanVisualizer<'a> {
 
 macro_rules! mtd {
     ($T:ty,$name:ident) => {
-        fn $name(&mut self, n: &$T, _: &dyn swc_css_visit::Node) {
+        fn $name(&mut self, n: &$T) {
             self.handler
                 .struct_span_err(n.span(), stringify!($T))
                 .emit();
@@ -349,7 +349,7 @@ impl Visit for SpanVisualizer<'_> {
     mtd!(UnknownAtRule, visit_unknown_at_rule);
     mtd!(ViewportRule, visit_viewport_rule);
 
-    fn visit_token_and_span(&mut self, n: &TokenAndSpan, _parent: &dyn swc_css_visit::Node) {
+    fn visit_token_and_span(&mut self, n: &TokenAndSpan) {
         self.handler
             .struct_span_err(n.span, &format!("{:?}", n.token))
             .emit();
@@ -379,10 +379,7 @@ fn span(input: PathBuf) {
 
         match stylesheet {
             Ok(stylesheet) => {
-                stylesheet.visit_with(
-                    &Invalid { span: DUMMY_SP },
-                    &mut SpanVisualizer { handler: &handler },
-                );
+                stylesheet.visit_with(&mut SpanVisualizer { handler: &handler });
 
                 Err(())
             }
